@@ -93,7 +93,13 @@ class Command(ResourceCommand):
 
 
 def install_theme(templates_dest, resources_dest):
-    for template_dir in django_settings.TEMPLATE_DIRS:
+    if (not os.path.exists(templates_dest)
+        and os.path.isdir(os.path.dirname(templates_dest))):
+        # subdirectory in a directory already present. We are OK with that.
+        os.makedirs(templates_dest)
+    for template_dir in [django_settings.TEMPLATE_DIRS[0]]:
+        # The first TEMPLATE_DIRS usually contains the most specialized
+        # templates (ie. the ones we truely want to install).
         if (templates_dest
             and not os.path.samefile(template_dir, templates_dest)):
             install_templates(template_dir, templates_dest)
